###########################################################################################################################################################################################
# This is a simple example how to run a series single-point (no-geometry-optimization) calculations with moving the hydrogen in the y direction                                           #
# Note: To run this script, you must be in a directoy which contains                                                                                                                      #
#	- a geometry.in file with optimized Al FCC(110) surface with hydrogen as an adsorbate                                                                                             #
#	- a control.template file which contains the correct method but with no-geometry optimization in it                                                                               #
# Example input files are provided in the same directory as this script                                                                                                                   #
###########################################################################################################################################################################################
import os, sys, shutil, glob, argparse
from shutil import copyfile
import numpy as np
from ase.io import read,write
from ase import atoms
from ase.constraints import FixAtoms

# parse command-line arguments
p = argparse.ArgumentParser()
p.add_argument('nproc', metavar='N', type=int, nargs=1 ,help='')
args = p.parse_args()

#Variable defintion:
AIMSBIN='aims.x'
energies=[]
#Loop over different points of H moving along the ln
for k in range(10):
    print ("point", k)
    f="out_"+str(k)+".txt"                                                           # creating new directory for each amount of k-points
    os.system('mpirun -np '+str(args.nproc[0])+' '+AIMSBIN+' > '+f)                  # run aims
    ffile = open(f)
    for line in ffile:
        if '| Total energy of the DFT / Hartree-Fock s.c.f. calculation      :' in line: # finding the energies in the output files
            energies.append([k,float(line.split()[-2])])
            #float(line.split()[-2])
            break        
    try:                                                                              # we don't know if there will be any optimization - therefore we don't knwo if the geometry.in.next step file will be generated
        surf = read('geometry.in.next_step')                                          # read geometry.in.next_step into ASE if there is any
    except:
        surf = read('geometry.in')                                                    # read geometry.in into ASE
    write('tmp.xyz',surf)                                                             # writing temporary xyz file
    cell = surf.get_cell(); pbc = surf.get_pbc(); del surf;                           # Trick because of problems with y-constraint in ASE atoms and write
    surf = read('tmp.xyz'); surf.set_cell(cell); surf.set_pbc(pbc);                   # Reseting geometry and cell
    c= FixAtoms(mask=[atom.position[2] < 16.0 for atom in surf])                      # Reseting constraints
    surf.set_constraint(c)
    write('geometry_'+str(k)+'.in',surf)                                              # store the (optimized) geometry from the step
    os.system('cat tmp.xyz >> relaxed_path.xyz; rm tmp.xyz')                          # storing an movine-like xyz file, how the hydrogen atom is moving
    move = np.zeros((surf.get_number_of_atoms(),3))                                   # creating an array, how the atoms of the surface will be moved
    move[-1,1]=0.2821356056934325                                                     # last atom - Hydrogen - will be moved in the y direction
    surf.translate(move)                                                              # applying the translation 
    write('geometry.in',surf)                                                         # writing new geometry.in file
    os.system('echo "  constrain_relaxation y" >> geometry.in')                       # reseting y-constrain for the Hydrogen atom

np.savetxt('energies_relaxed_line_scan.txt',energies)

print ("Done")


